@@ -7,7 +7,7 @@ RDF::Query::Algebra::BasicGraphPattern - Algebra class for BasicGraphPattern pat
 
 =head1 VERSION
 
-This document describes RDF::Query::Algebra::BasicGraphPattern version 2.908.
+This document describes RDF::Query::Algebra::BasicGraphPattern version 2.910.
 
 =cut
 
@@ -30,7 +30,7 @@ use RDF::Trine::Iterator qw(smap swatch);
 our ($VERSION);
 my %AS_SPARQL;
 BEGIN {
-	$VERSION	= '2.908';
+	$VERSION	= '2.910';
 }
 
 ######################################################################
@@ -252,14 +252,7 @@ sub definite_variables {
 	return RDF::Query::_uniq(map { $_->definite_variables } $self->triples);
 }
 
-=item C<< check_duplicate_blanks >>
-
-Returns true if blank nodes respect the SPARQL rule of no blank-label re-use
-across BGPs, otherwise throws a RDF::Query::Error::QueryPatternError exception.
-
-=cut
-
-sub _check_duplicate_blanks {
+sub _referenced_blanks {
 	my $self	= shift;
 	my %seen;
 	foreach my $t ($self->triples) {
