@@ -7,7 +7,7 @@ RDF::Query::Algebra::GroupGraphPattern - Algebra class for GroupGraphPattern pat
 
 =head1 VERSION
 
-This document describes RDF::Query::Algebra::GroupGraphPattern version 2.908.
+This document describes RDF::Query::Algebra::GroupGraphPattern version 2.910.
 
 =cut
 
@@ -32,7 +32,7 @@ use RDF::Trine::Iterator qw(sgrep smap swatch);
 our ($VERSION, $debug);
 BEGIN {
 	$debug		= 0;
-	$VERSION	= '2.908';
+	$VERSION	= '2.910';
 	our %SERVICE_BLOOM_IGNORE	= ('http://dbpedia.org/sparql' => 1);	# by default, assume dbpedia doesn't implement k:bloom().
 }
 
@@ -278,6 +278,34 @@ sub definite_variables {
 	return RDF::Query::_uniq(map { $_->definite_variables } $self->patterns);
 }
 
+=item C<< check_duplicate_blanks >>
+
+Returns true if blank nodes respect the SPARQL rule of no blank-label re-use
+across BGPs, otherwise throws a RDF::Query::Error::QueryPatternError exception.
+
+=cut
+
+sub check_duplicate_blanks {
+	my $self	= shift;
+	my @data;
+	foreach my $arg ($self->construct_args) {
+		if (blessed($arg) and $arg->isa('RDF::Query::Algebra')) {
+			push(@data, $arg->_referenced_blanks());
+		}
+	}
+	
+	my %seen;
+	foreach my $d (@data) {
+		foreach my $b (@$d) {
+			if ($seen{ $b }++) {
+				throw RDF::Query::Error::QueryPatternError -text => "Same blank node identifier ($b) used in more than one BasicGraphPattern.";
+			}
+		}
+	}
+	
+	return 1;
+}
+
 1;
 
 __END__
